@@ -24,7 +24,7 @@ from TileSeqMut import locate_mut
 
 class readSam(object):
 
-    def __init__(self, sam_r1, sam_r2, param, arguments, output_dir, cores):
+    def __init__(self, sam_r1, sam_r2, param, arguments, output_dir, cores, loggerobj):
         """
         sam_R1: read one of the sample
         sam_R2: read two of the sample
@@ -63,16 +63,17 @@ class readSam(object):
         self._seq_lookup = help_functions.build_lookup(self._cds_start.values.item(), self._seq.cds_end.values.item(), self._cds_seq)
 
         # init a new object for logging, log to sample specific file.log
-        log_f = os.path.join(output_dir, f"sample_{str(self._sample_id)}_mut_count.log")
-        log_object = help_functions.logginginit(arguments.log_level, log_f)
+        # log_f = os.path.join(output_dir, f"sample_{str(self._sample_id)}_mut_count.log")
+        # log_object = help_functions.logginginit(arguments.log_level, log_f)
 
         self._sample_counts_f = os.path.join(self._output_counts_dir,f"counts_sample_{self._sample_id}.csv")
         self._sample_counts_r1_f = os.path.join(self._output_counts_dir, f"counts_sample_{self._sample_id}_r1.csv")
         self._sample_counts_r2_f = os.path.join(self._output_counts_dir, f"counts_sample_{self._sample_id}_r2.csv")
 
-        self._mut_log = log_object.getLogger("count.mut")
-        self._locate_log = log_object.getLogger("locate.mut")
-
+        self._base = arguments.base
+        # self._mut_log = log_object.getLogger("count.mut")
+        # self._locate_log = log_object.getLogger("locate.mut")
+        self._mut_log = loggerobj
         self._mut_log.info(f"Counting mutations in sample-{self._sample_id}")
         self._mut_log.info(f"Sam file input R1:{sam_r1}")
         self._mut_log.info(f"Sam file input R2:{sam_r2}")
@@ -221,7 +222,9 @@ class readSam(object):
                 # pass this dictionary to locate mut
                 # mut = locate_mut_main()
                 # add mutation to mut list
-                mut_parser = locate_mut.MutParser(row, self._seq, self._cds_seq, self._seq_lookup, self._tile_begins, self._tile_ends, self._qual, self._locate_log, self._mutrate)
+                mut_parser = locate_mut.MutParser(row, self._seq, self._cds_seq, self._seq_lookup,
+                                                  self._tile_begins, self._tile_ends, self._qual,
+                                                  self._mut_log, self._mutrate, self._base)
                 hgvs, outside_mut, pos_df, all_posterior= mut_parser._main()
                 if len(hgvs) !=0:
                     final_pairs +=1
@@ -262,7 +265,10 @@ class readSam(object):
         # convert list to df with one col
         hgvs_df = pd.DataFrame.from_dict(hgvs_output, orient="index")
         hgvs_df = hgvs_df.reset_index()
-        hgvs_df.columns = ["HGVS", "count"]
+        if not hgvs_df.empty:
+            hgvs_df.columns = ["HGVS", "count"]
+        else:
+            hgvs_df = pd.DataFrame({}, columns=["HGVS", "count"])
         hgvs_df.to_csv(self._sample_counts_f, mode="a", index=False)
 
     def multi_core(self):
@@ -297,7 +303,9 @@ class readSam(object):
 
             line_r1 = line_r1.split()
             line_r2 = line_r2.split()
-            if len(line_r1) <= 1:
+            if len(line_r1) < 9 or len(line_r2) < 9:
+                # the read has no sequence
+                self._mut_log.warning("Missing fields in read!")
                 continue
 
             read_pair += 1  # count how many read pairs in this pair of sam files
@@ -329,6 +337,7 @@ class readSam(object):
             if (int(pos_start_r2) - int(self._cds_start)) > (int(self._tile_ends) - int(self._min_map_len)):
                 off_read += 1
                 continue
+
             # get CIGAR string
             CIGAR_r1 = line_r1[5]
             seq_r1 = line_r1[9]
@@ -351,8 +360,7 @@ class readSam(object):
             else:
                 mdz_r2 = ""
 
-            if ((not re.search('[a-zA-Z]', mdz_r1)) and ("I" not in CIGAR_r1)) and (
-                    (not re.search('[a-zA-Z]', mdz_r2)) and ("I" not in CIGAR_r2)):
+            if (not re.search('[a-zA-Z]', mdz_r1)) and ("I" not in CIGAR_r1) and ("D" not in CIGAR_r2) and (not re.search('[a-zA-Z]', mdz_r2)) and ("I" not in CIGAR_r2) and ("D" not in CIGAR_r2):
                 # if MDZ string only contains numbers
                 # and no insertions shown in CIGAR string
                 # means there is no mutation in this read
@@ -378,7 +386,8 @@ class readSam(object):
             # mut_parser = locate_mut.MutParser(row, self._seq, self._cds_seq, self._seq_lookup, self._tile_begins,
                                               # self._tile_ends, self._qual, self._locate_log, self._mutrate)
             jobs.append(pool.apply_async(process_wrapper, (row, self._seq, self._cds_seq, self._seq_lookup, self._tile_begins,
-                                               self._tile_ends, self._qual, self._locate_log, self._mutrate)))
+                                               self._tile_ends, self._qual, self._mut_log, self._mutrate,
+                                                           self._base)))
             row = {} # flush
 
         r1_f.close()
@@ -451,21 +460,25 @@ class readSam(object):
         # convert list to df with one col
         hgvs_df = pd.DataFrame.from_dict(hgvs_output, orient="index")
         hgvs_df = hgvs_df.reset_index()
-        hgvs_df.columns = ["HGVS", "count"]
+        if not hgvs_df.empty:
+            hgvs_df.columns = ["HGVS", "count"]
         hgvs_df.to_csv(self._sample_counts_f, mode="a", index=False)
+        del hgvs_df
 
         r1_df = pd.DataFrame.from_dict(r1_pop_hgvs, orient="index")
         r1_df = r1_df.reset_index()
         if not r1_df.empty:
             r1_df.columns = ["HGVS", "count"]
         r1_df.to_csv(self._sample_counts_r1_f, mode="a", index=False)
+        del r1_f
 
         r2_df = pd.DataFrame.from_dict(r2_pop_hgvs, orient="index")
         r2_df = r2_df.reset_index()
         if not r2_df.empty:
             r2_df.columns = ["HGVS", "count"]
         r2_df.to_csv(self._sample_counts_r2_f, mode="a", index=False)
-        #
+
+        del r2_f
         # self._mut_log.info(f"Reading posterior filtered dfs ...")
         #
         # # pos_df = pd.concat(pos_df)
@@ -479,13 +492,14 @@ class readSam(object):
         for df in all_df:
             df.to_csv(all_f, mode='a', header=False, index=False)
         self._mut_log.info(f"Posterior df saved to files ... {all_f}")
+        del all_f
 
-
-def process_wrapper(row, seq, cds_seq, seq_lookup, tile_begins, tile_ends, qual, locate_log, mutrate):
+def process_wrapper(row, seq, cds_seq, seq_lookup, tile_begins, tile_ends, qual, locate_log, mutrate, base):
     """
 
     """
-    mut_parser = locate_mut.MutParser(row, seq, cds_seq, seq_lookup, tile_begins, tile_ends, qual, locate_log, mutrate)
+    mut_parser = locate_mut.MutParser(row, seq, cds_seq, seq_lookup, tile_begins, tile_ends, qual, locate_log,
+                                      mutrate, base)
     hgvs, outside_mut, all_df, hgvs_r1_clusters, hgvs_r2_clusters = mut_parser._main()
     return hgvs, outside_mut, all_df, hgvs_r1_clusters, hgvs_r2_clusters
 
