@@ -236,8 +236,8 @@ class fastq2counts(object):
         self._log.info("Counting mutations ...")
         # submit job with main.py -r1 and -r2
         # run main.py with -r1 and -r2
-
-        mut_counts = count_mut.readSam(self._r1, self._r2, self._param_json, self._args, self._output, self._args.c)
+        logger_mut = self._logging.getLogger("count.mut.log")
+        mut_counts = count_mut.readSam(self._r1, self._r2, self._param_json, self._args, self._output, self._args.c, logger_mut)
         # start = time.time()
         if self._args.test:
             self._log.info("Testing... ")
@@ -270,6 +270,7 @@ class fastq2counts(object):
         for i in self._sample_names:
             sam_f_r1 = glob.glob(f"{sam_dir}{i}_*R1_*.sam") # assume all the sam files have the same name format (id_*.sam)
             sam_f_r2 = glob.glob(f"{sam_dir}{i}_*R2_*.sam")
+            mut_log_file = os.path.join(self._output)
             if len(sam_f_r1) == 0 or len(sam_f_r2) == 0:
                 self._log.error(f"SAM file for sample {i} not found. Please check your parameter file")
                 exit(1)
@@ -349,12 +350,12 @@ class fastq2counts(object):
                 os.makedirs(self._output)
 
             # output directory is the mut_count dir
-            # make folder to store all the sh files
+            # make folder to store all the sh files as well as all the log files
             if self._args.environment == "BC2" or self._args.environment == "BC":
-                sh_output = os.path.join(self._output, "BC_mut_sh")
+                sh_output = os.path.join(self._output, "BC_jobs")
 
             elif self._args.environment == "DC":
-                sh_output = os.path.join(self._output, "DC_mut_sh")
+                sh_output = os.path.join(self._output, "DC_jobs")
 
             else:
                 self._log.error("Please provide valid environment: BC/BC2/DC")
@@ -518,7 +519,8 @@ if __name__ == "__main__":
     parser.add_argument("-o", "--output", help="Output folder", type=str, required=True)
     parser.add_argument("-p", "--param", help="csv paramter file", type=str, required=True)
     parser.add_argument("-n", "--name", help="Name for this run", type=str, required=True)
-    parser.add_argument("--skip_alignment", action="store_true", help="skip alignment for this analysis, ONLY submit jobs for counting mutations in existing output folder")
+    parser.add_argument("--skip_alignment", action="store_true", help="skip alignment for this analysis, "
+                                                                      "ONLY submit jobs for counting mutations in existing output folder")
     parser.add_argument("-r1", help="r1 SAM file", type=str)
     parser.add_argument("-r2", help="r2 SAM file", type=str)
 
@@ -532,12 +534,11 @@ if __name__ == "__main__":
     parser.add_argument("-mt", type = int, help="Mutation call time \
         (default = 48h)", default=48)
     parser.add_argument("-c", type=int, help="Number of cores", default=16)
+    parser.add_argument("-b", "--base", help="ASCII code base", default=33)
     parser.add_argument("-test", action="store_true", help="Turn on testing mode")
-    parser.add_argument("-rc", action="store_true", help="Turn on detect rc mode")
-    ##parser.add_argument("-qual", "--quality", help="Posterior threshold for \
-    ##    filtering mutations (default = 0.99)", type=float, default = 0.99)
-    ##parser.add_argument("-min", "--min_cover", help="Minimal percentage required to \
-    ##    cover the tile (default = 0.4)", type=float, default=0.6)
+    parser.add_argument("-rc", action="store_true", help="Turn on rc mode, both direction of the reads will be "
+                                                         "aligned to the reference. Variant calling will be "
+                                                         "performed on all the reads that are aligned (BE CAREFUL!)")
 
     parser.add_argument("-override", "--sr_Override", action="store_true", help="Provide this argument when there is only one replicate")
 
